s1etad package
==============

.. automodule:: s1etad
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   s1etad.cli

Submodules
----------

.. toctree::
   :maxdepth: 4

   s1etad.geometry
   s1etad.kmz
   s1etad.product
   s1etad.utils
